@@ -273,7 +273,7 @@ class Service(object):
             raise EmsServiceException("There is no projects key in response")
         return [EmsProject(self.session, project) for project in projects]
 
-    def add_project(self, project_name, description=""):
+    def add_project(self, project_name, password=None, description=""):
         """
         Add a new Project to the current Service.
 
@@ -299,6 +299,9 @@ class Service(object):
             "description": description,
         }
 
+        if password is not None:
+            request_parameters["password"] = password
+
         response_dict = self._ems_request(url, request_parameters, "POST")
 
         try:
