@@ -252,6 +252,8 @@ def main():
 
     parser_dump.add_argument("--objectclasses", type=str, help="List of objectclasses")
 
+    parser_dump.add_argument("--layers", type=str, help="List of layers")
+
     # Load
     parser_load = subparsers.add_parser(
         "load", help="Imports a project from a directory ", parents=[parent_parser]
@@ -417,6 +419,11 @@ def main():
         if args.objectclasses == "":
             args.objectclasses = None
 
+        if args.layers == "":
+            args.layers = None
+        else:
+            args.layers.split(",")
+
         my_emsclidump = EmsCliDump(
             url=args.url,
             username=args.username,
@@ -434,6 +441,7 @@ def main():
             extension=args.format,
             objectclasses=args.objectclasses,
             variants=args.variants,
+            export_layers=args.layers,
         )
 
     logger.info("EMS_CLI completed")
